@@ -19,7 +19,7 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Cambridge, MA 02110-1301, USA
 
 */
 // Self
-#include "semanticinfocontextmanageritem.moc"
+#include "semanticinfocontextmanageritem.h"
 
 // Qt
 #include <QEvent>
@@ -28,15 +28,16 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Cambridge, MA 02110-1301, USA
 #include <QSignalMapper>
 #include <QStyle>
 #include <QTimer>
+#include <QAction>
 
 // KDE
-#include <KAction>
 #include <KActionCategory>
 #include <KActionCollection>
-#include <KDebug>
 #include <KDialog>
-#include <KLocale>
+#include <KLocalizedString>
 #include <KRatingPainter>
+#include <KIconLoader>
+#include <KSharedConfig>
 
 // Local
 #include "viewmainpage.h"
@@ -81,7 +82,7 @@ struct SemanticInfoDialog : public KDialog, public Ui_SemanticInfoDialog
 
     KConfigGroup configGroup() const
     {
-        KSharedConfigPtr config = KGlobal::config();
+        KSharedConfigPtr config = KSharedConfig::openConfig();
         return KConfigGroup(config, "SemanticInfoDialog");
     }
 };
@@ -162,10 +163,10 @@ struct SemanticInfoContextManagerItemPrivate : public Ui_SemanticInfoSideBarItem
     ViewMainPage* mViewMainPage;
     QPointer<SemanticInfoDialog> mSemanticInfoDialog;
     TagInfo mTagInfo;
-    KAction* mEditTagsAction;
+    QAction * mEditTagsAction;
     QSignalMapper* mRatingMapper;
     /** A list of all actions, so that we can disable them when necessary */
-    QList<KAction*> mActions;
+    QList<QAction *> mActions;
     QPointer<RatingIndicator> mRatingIndicator;
 
     void setupGroup()
@@ -196,14 +197,14 @@ struct SemanticInfoContextManagerItemPrivate : public Ui_SemanticInfoSideBarItem
 
         mEditTagsAction = edit->addAction("edit_tags");
         mEditTagsAction->setText(i18nc("@action", "Edit Tags"));
-        mEditTagsAction->setShortcut(Qt::CTRL | Qt::Key_T);
+        mActionCollection->setDefaultShortcut(mEditTagsAction, Qt::CTRL + Qt::Key_T);
         QObject::connect(mEditTagsAction, SIGNAL(triggered()),
                          q, SLOT(showSemanticInfoDialog()));
         mActions << mEditTagsAction;
 
         mRatingMapper = new QSignalMapper(q);
         for (int rating = 0; rating <= 5; ++rating) {
-            KAction* action = edit->addAction(QString("rate_%1").arg(rating));
+            QAction * action = edit->addAction(QString("rate_%1").arg(rating));
             if (rating == 0) {
                 action->setText(i18nc("@action Rating value of zero", "Zero"));
             } else {
@@ -265,7 +266,7 @@ SemanticInfoContextManagerItem::SemanticInfoContextManagerItem(ContextManager* m
             SLOT(slotSelectionChanged()));
     connect(contextManager(), SIGNAL(selectionDataChanged()),
             SLOT(update()));
-    connect(contextManager(), SIGNAL(currentDirUrlChanged(KUrl)),
+    connect(contextManager(), SIGNAL(currentDirUrlChanged(QUrl)),
             SLOT(update()));
 
     d->setupActions();
@@ -356,7 +357,7 @@ void SemanticInfoContextManagerItem::update()
     }
 
     bool enabled = !contextManager()->selectedFileItemList().isEmpty();
-    Q_FOREACH(KAction * action, d->mActions) {
+    Q_FOREACH(QAction * action, d->mActions) {
         action->setEnabled(enabled);
     }
     d->updateTagLabel();
