@@ -19,7 +19,7 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Cambridge, MA 02110-1301, USA
 
 */
 // Self
-#include "rasterimageview.moc"
+#include "rasterimageview.h"
 
 // Local
 #include <lib/documentview/abstractrasterimageviewtool.h>
@@ -28,13 +28,13 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Cambridge, MA 02110-1301, USA
 #include <lib/gvdebug.h>
 
 // KDE
-#include <KDebug>
 
 // Qt
 #include <QGraphicsSceneMouseEvent>
 #include <QPainter>
 #include <QTimer>
 #include <QWeakPointer>
+#include <QDebug>
 
 // LCMS2
 #include <lcms2.h>
@@ -85,7 +85,7 @@ struct RasterImageViewPrivate
         }
         Cms::Profile::Ptr monitorProfile = Cms::Profile::getMonitorProfile();
         if (!monitorProfile) {
-            kWarning() << "Could not get monitor color profile";
+            qWarning() << "Could not get monitor color profile";
             return;
         }
 
@@ -96,7 +96,7 @@ struct RasterImageViewPrivate
             cmsFormat = TYPE_BGRA_8;
             break;
         default:
-            kWarning() << "This image has a color profile, but Gwenview can only apply color profile on RGB32 or ARGB32 images";
+            qWarning() << "This image has a color profile, but Gwenview can only apply color profile on RGB32 or ARGB32 images";
             return;
         }
         mDisplayTransform = cmsCreateTransform(profile->handle(), cmsFormat,
@@ -120,8 +120,7 @@ struct RasterImageViewPrivate
         mUpdateTimer = new QTimer(q);
         mUpdateTimer->setInterval(500);
         mUpdateTimer->setSingleShot(true);
-        QObject::connect(mUpdateTimer, SIGNAL(timeout()),
-                         q, SLOT(updateBuffer()));
+        QObject::connect(mUpdateTimer, SIGNAL(timeout()), q, SLOT(updateBuffer()));
     }
 
     void startAnimationIfNecessary()
@@ -200,8 +199,7 @@ RasterImageView::RasterImageView(QGraphicsItem* parent)
 
     d->mBufferIsEmpty = true;
     d->mScaler = new ImageScaler(this);
-    connect(d->mScaler, SIGNAL(scaledRect(int,int,QImage)),
-            SLOT(updateFromScaler(int,int,QImage)));
+    connect(d->mScaler, &ImageScaler::scaledRect, this, &RasterImageView::updateFromScaler);
 
     d->createBackgroundTexture();
     d->setupUpdateTimer();
@@ -240,7 +238,7 @@ void RasterImageView::loadFromDocument()
         return;
     }
 
-    connect(doc.data(), SIGNAL(metaInfoLoaded(KUrl)),
+    connect(doc.data(), SIGNAL(metaInfoLoaded(QUrl)),
             SLOT(slotDocumentMetaInfoLoaded()));
     connect(doc.data(), SIGNAL(isAnimatedUpdated()),
             SLOT(slotDocumentIsAnimatedUpdated()));
@@ -258,7 +256,7 @@ void RasterImageView::slotDocumentMetaInfoLoaded()
     } else {
         // Could not retrieve image size from meta info, we need to load the
         // full image now.
-        connect(document().data(), SIGNAL(loaded(KUrl)),
+        connect(document().data(), SIGNAL(loaded(QUrl)),
                 SLOT(finishSetDocument()));
         document()->startLoadingFullImage();
     }
