@@ -27,10 +27,10 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 // Qt
 #include <QImage>
 #include <QPainter>
+#include <QDebug>
 
 // KDE
-#include <KDebug>
-#include <KLocale>
+#include <KLocalizedString>
 
 // Local
 #include "ramp.h"
@@ -93,7 +93,7 @@ void RedEyeReductionImageOperation::redo()
 void RedEyeReductionImageOperation::undo()
 {
     if (!document()->editor()) {
-        kWarning() << "!document->editor()";
+        qWarning() << "!document->editor()";
         return;
     }
     QImage img = document()->image();
